{
  description = "Syndicate utilities";

  inputs.rust.url = "github:oxalica/rust-overlay";

  outputs = { self, nixpkgs, rust }: {
    lib = nixpkgs.lib.extend (import ./lib.nix);

    overlays.default = final: prev:
      let rust' = (prev.extend rust.overlay).rust-bin.nightly.latest.default;
      in {
        inherit (self) lib;

        nimPackages = prev.nimPackages.overrideScope' (final': prev': {
          preserves = final'.callPackage ./preserves-nim { };
        });

        preserves-tools = final.callPackage ./preserves-tools { rust = rust'; };
        syndicate-server =
          final.callPackage ./syndicate-server { rust = rust'; };
      };

    legacyPackages =
      self.lib.mapAttrs (system: pkgs: pkgs.extend self.overlays.default) {
        inherit (nixpkgs.legacyPackages) aarch64-linux x86_64-linux;
      };

    packages = self.lib.mapAttrs (system: pkgs:
      with pkgs; {
        inherit preserves-tools syndicate-server;
        preserves-nim = nimPackages.preserves;
      }) self.legacyPackages;

    nixosModules.syndicate-server =
      # A little hack to apply our overlay to this module only.
      let f = import ./nixos/syndicate-server.nix;
      in { config, lib, pkgs, ... }:
      f {
        inherit config lib;
        pkgs = pkgs.extend self.overlays.default;
      };

    devShells = self.lib.mapAttrs (system: pkgs:
      with pkgs; {
        default =
          mkShell { packages = builtins.attrValues self.packages.${system}; };
      }) self.legacyPackages;

  };
}
